import configparser
import os


class PyAxonautConfig:

    def __init__(self):
        dir_path = os.path.dirname(os.path.realpath(__file__))
        config = configparser.ConfigParser()
        config.read(f'{dir_path}/config.ini')
        self.config = config



import json
import unittest
import os
from unittest.mock import Mock, patch

from pyaxonaut import Customers


class TestCustomers(unittest.TestCase):

    def setUp(self):
        self._customers = Customers()
        with open(f"{os.path.dirname(os.path.realpath(__file__))}/fixtures/customers.json",
                  mode="r") as json_customers_fixture:
            self.json_customers = json.load(json_customers_fixture)
        with open(f"{os.path.dirname(os.path.realpath(__file__))}/fixtures/customer.json",
                  mode="r") as json_customer_fixture:
            self.json_customer = json.load(json_customer_fixture)

    def _mock_response(
            self,
            status=200,
            content="CONTENT",
            json_data=None,
            raise_for_status=None):
        mock_resp = Mock()
        # mock raise_for_status call w/optional error
        mock_resp.raise_for_status = Mock()
        if raise_for_status:
            mock_resp.raise_for_status.side_effect = raise_for_status
        # set status code and content
        mock_resp.status_code = status
        mock_resp.content = content
        # add json data if provided
        if json_data:
            mock_resp.json = Mock(
                return_value=json_data
            )
        return mock_resp

    @patch('pyaxonaut.customers.requests.post')
    def test_get_customers(self, mock_post):
        mock_resp = self._mock_response(json_data=self.json_customers)
        mock_post.return_value = mock_resp

        response = self._customers.get_customers()
        self.assertTrue(len(response) > 0)
        self.assertEqual(987654, response[0].company_id)
        self.assertEqual(987655, response[1].company_id)

    @patch('pyaxonaut.customers.requests.post')
    def test_get_customer_from_id(self, mock_post):
        mock_resp = self._mock_response(json_data=self.json_customer)
        mock_post.return_value = mock_resp

        customer = self._customers.get_customer(company_id="987654")
        self.assertEqual(987654, customer.company_id)



import requests

from pyaxonaut.constants import AXONAUT_API_CUSTOMERS_LIST, AXONAUT_API_BASE_URL, AXONAUT_API_CUSTOMER
from pyaxonaut.models.customer import Customer


class Customers:
    CUSTOMERS_URL = f"{AXONAUT_API_BASE_URL}/{AXONAUT_API_CUSTOMERS_LIST}"
    CUSTOMER_URL = f"{AXONAUT_API_BASE_URL}/{AXONAUT_API_CUSTOMER}"

    def __init__(self, api_key=None):
        self.api_key = api_key

    def get_customers(self):
        return list(map(Customer, self.request_customers_json()))

    def get_customer(self, company_id):
        return Customer(self.request_customer_json(company_id=company_id))

    def request_customers_json(self):
        resp = requests.post(self.CUSTOMERS_URL, data={
            "accountApiKey": self.api_key
        })
        return resp.json().get('arrayCompanies')

    def request_customer_json(self, company_id):
        resp = requests.post(self.CUSTOMER_URL, data={
            "accountApiKey": self.api_key,
            "companyId": company_id
        })
        return resp.json().get('arrayCompanies')[0]



class Customer:
    company_id = ""
    company_name = ""
    company_address_street = ""
    company_address_zip_code = ""
    company_address_town = ""
    company_address_country = ""
    nb_opportunities = 0
    is_prospect = False
    is_customer = False
    is_supplier = False

    def __init__(self, json_customer):
        self.company_id = json_customer.get('companyId')
        self.company_name = json_customer.get('name')
        self.company_address_street = json_customer.get('addressStreet')
        self.company_address_zip_code = json_customer.get('addressZipCode')
        self.company_address_town = json_customer.get('addressTown')
        self.company_address_country = json_customer.get('addressCountry')
        self.nb_opportunities = json_customer.get('nbOpportunities')
        self.is_prospect = json_customer.get('isProspect')
        self.is_customer = json_customer.get('isCustomer')
        self.is_supplier = json_customer.get('isSupplier')



import unittest

from ..models.customer import Customer


class TestCustomerModel(unittest.TestCase):

    def test_get_customer_from_json(self):
        json_customer = {
            "companyId": 123456,
            "name": "Test Company",
            "addressStreet": "3 Rabbit street",
            "addressZipCode": "1234",
            "addressTown": "Rabbit Town",
            "addressCountry": "Wonderland",
            "nbOpportunities": 12,
            "isProspect": True,
            "isCustomer": False,
            "isSupplier": False
        }
        customer = Customer(json_customer)
        self.assertEqual(json_customer.get("companyId"), customer.company_id)
        self.assertEqual(json_customer.get("name"), customer.company_name)
        self.assertEqual(json_customer.get("addressStreet"), customer.company_address_street)
        self.assertEqual(json_customer.get("addressZipCode"), customer.company_address_zip_code)
        self.assertEqual(json_customer.get("addressTown"), customer.company_address_town)
        self.assertEqual(json_customer.get("addressCountry"), customer.company_address_country)
        self.assertEqual(json_customer.get("nbOpportunities"), customer.nb_opportunities)
        self.assertEqual(json_customer.get("isProspect"), customer.is_prospect)
        self.assertEqual(json_customer.get("isCustomer"), customer.is_customer)
        self.assertEqual(json_customer.get("isSupplier"), customer.is_supplier)


import setuptools
from pkg_resources import parse_requirements

with open("README.md", "r") as fh:
    long_description = fh.read()

with open('requirements.txt') as fp:
    install_requires = fp.read()

setuptools.setup(
    name="pyaxonaut",
    version="0.0.1",
    author="AJ Innov",
    author_email="contact@ajinov.fr",
    description="A non official API wrapper for Axonaut CRM",
    install_requires=install_requires,
    long_description=long_description,
    long_description_content_type="text/markdown",
    url="https://github.com/antoine-briand/pyaxonaut",
    packages=setuptools.find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
)
